/* Autor: Victor Rusu
 * Complexitate: O(N log N)
 */

#include <cstdio>
#include <cassert>
#include <vector>
#include <map>
#include <algorithm>

using namespace std;

#define MAX_N 200015
#define MAX_AI 1048576

struct event {
    int x, y, tip, ind;
    bool operator<(const event& other) const {
        if (x < other.x)
            return true;
        if (x > other.x)
            return false;
        if (tip < other.tip)
            return true;
        return false;
    }
    event(int X, int Y, int Tip, int Ind = 0) {
        x = X;
        y = Y;
        tip = Tip;
        ind = Ind;
    }
};

int N, M;
int AIleft[MAX_AI];
int AIright[MAX_AI];
int X[MAX_N], Y[MAX_N], R[MAX_N];
int Sol[MAX_N];
vector<int> V;
vector<event> Elist;

void read() {
    assert(scanf("%d %d", &N, &M) == 2);
    for (int i = 1; i <= N; ++i) {
        int x, y;
        assert(scanf("%d %d", &x, &y) == 2);
        V.push_back(y);
        event e1(x, y, 2);
        Elist.push_back(e1);
    }
    for (int i = 1; i <= M; ++i) {
        assert(scanf("%d %d %d", &X[i], &Y[i], &R[i]) == 3);
        V.push_back(Y[i]);
        event e1(X[i] - R[i], Y[i], 1, i);
        event e2(X[i] + R[i], Y[i], 3, i);
        Elist.push_back(e1);
        Elist.push_back(e2);
    }
}

void update(int nod, int st, int dr, int pos, int val) {
    if (st == dr) {
        AIleft[nod] = val;
        AIright[nod] = val;
    } else {
        int mij = (st + dr) / 2, fst = nod * 2, fdr = nod * 2 + 1;
        if (pos <= mij)
            update(fst, st, mij, pos, val);
        else
            update(fdr, mij + 1, dr, pos, val);

        if (AIleft[fdr] != 0)
            AIleft[nod] = AIleft[fdr];
        else
            AIleft[nod] = AIleft[fst];

        if (AIright[fst] != 0)
            AIright[nod] = AIright[fst];
        else
            AIright[nod] = AIright[fdr];
    }
}

int left_query(int nod, int st, int dr, int a, int b) {
    if (a <= st && dr <= b) {
        return AIleft[nod];
    } else {
        int mij = (st + dr) / 2, fst = nod * 2, fdr = nod * 2 + 1;
        int rst, rdr;
        rst = rdr = 0;
        if (a <= mij)
            rst = left_query(fst, st, mij, a, b);
        if (mij < b)
            rdr = left_query(fdr, mij + 1, dr, a, b);
        if (rdr != 0)
            return rdr;
        else
            return rst;
    }
}

int right_query(int nod, int st, int dr, int a, int b) {
    if (a <= st && dr <= b) {
        return AIright[nod];
    } else {
        int mij = (st + dr) / 2, fst = nod * 2, fdr = nod * 2 + 1;
        int rst, rdr;
        rst = rdr = 0;
        if (a <= mij)
            rst = right_query(fst, st, mij, a, b);
        if (mij < b)
            rdr = right_query(fdr, mij + 1, dr, a, b);
        if (rst != 0)
            return rst;
        else
            return rdr;
    }
}

bool dist(int x, int y, int cerc) {
    long long dist = ((long long)x - X[cerc]) * ((long long)x - X[cerc]) +
                     ((long long)y - Y[cerc]) * ((long long)y - Y[cerc]);
    return dist <= (long long)R[cerc] * R[cerc];
}

inline int Mp(int val) {
    return lower_bound(V.begin(), V.end(), val) - V.begin() + 1;
}

void solve() {
    sort(V.begin(), V.end());
    V.erase(unique(V.begin(), V.end()), V.end());
    int AIsize = V.size();

    sort(Elist.begin(), Elist.end());
    for (int i = 0; i < (int)Elist.size(); ++i) {
        if (Elist[i].tip == 1) {
            update(1, 1, AIsize, Mp(Elist[i].y), Elist[i].ind);
        }
        if (Elist[i].tip == 2) {
            int lind = left_query(1, 1, AIsize, 1, Mp(Elist[i].y));
            int rind = right_query(1, 1, AIsize, Mp(Elist[i].y), AIsize);

            if (lind && dist(Elist[i].x, Elist[i].y, lind))
                Sol[lind] += 1;
            if (rind && dist(Elist[i].x, Elist[i].y, rind) && rind != lind)
                Sol[rind] += 1;
        }
        if (Elist[i].tip == 3) {
            update(1, 1, AIsize, Mp(Elist[i].y), 0);
        }
    }
    for (int i = 1; i <= M; ++i)
        printf("%d\n", Sol[i]);
}

int main() {
    assert(freopen("nuke.in", "r", stdin));
    assert(freopen("nuke.out", "w", stdout));

    read();
    solve();

    return 0;
}
